"""Verifier exceptions."""
from typing import Sequence

from regal.exceptions import ContactDoesNotExist


class VerificationDoesNotExist(ValueError):
    """Verification does not exist."""


class MethodNotApplicable(ValueError):
    """Method is not applicable for this verification."""


class InvalidData(ValueError):
    """Invalid data."""

    def __init__(self, fields: Sequence[str]) -> None:  # pragma: no cover
        super().__init__()
        self.fields = fields


class IncorrectStatus(ValueError):
    """Verification is in incorrect status for purpose of the operation."""


__all__ = [
    "ContactDoesNotExist",
    "IncorrectStatus",
    "InvalidData",
    "MethodNotApplicable",
    "VerificationDoesNotExist",
]
