from datetime import date, datetime
from typing import Any
from unittest import TestCase

import pytz
from fred_api.verification.common_types_pb2 import ContactData as ContactDataMessage
from regal import Address

from verifier.common import ContactData, VerificationResult


class TestVerificationResult(TestCase):
    def test_success(self):
        data: Any = (
            ({"name": False}, False),
            ({"name": True, "address": False}, False),
            ({"name": True, "address": True}, True),
            ({}, True),
        )

        for kwargs, success in data:
            with self.subTest(kwargs=kwargs, success=success):
                result = VerificationResult(
                    verify_datetime=datetime(2020, 1, 1, tzinfo=pytz.utc),
                    method="eID",
                    data=ContactData(),
                    contact_history_id="ch:1",
                    **kwargs,
                )
                self.assertEqual(result.success, success)


class TestContactData(TestCase):
    def test_to_protobuf_empty(self):
        self.assertEqual(ContactData().to_protobuf(), ContactDataMessage())

    def test_to_protobuf_full(self):
        data = ContactData(
            name="Arnold Rimmer",
            organization="Jupiter Mining Company",
            birthdate=date(2224, 1, 1),
            company_registration_number="JMC123",
            address=Address(
                street=["Deck 4"],
                city="Red Dwarf",
                postal_code="12345",
                country_code="JMC",
            ),
            emails=["rimmer@example.org"],
        )
        message = ContactDataMessage()
        message.name = "Arnold Rimmer"
        message.organization = "Jupiter Mining Company"
        message.birthdate = "2224-01-01"
        message.company_registration_number = "JMC123"
        message.address.street[:] = ["Deck 4"]
        message.address.city = "Red Dwarf"
        message.address.postal_code = "12345"
        message.address.country_code = "JMC"
        message.emails[:] = ["rimmer@example.org"]

        self.assertEqual(data.to_protobuf(), message)
